# Maketree CLI

A CLI application to make complex directory structures in one go, Easily.


### Coming soon!
_Currently under development_, will be released in a couple of (maximum 4 or 5) years, MAYBE. (_just kidding!_)
